@@ -66,7 +66,9 @@ enum dump_format {
     0, \
     0, \
 \
-    0 \
+    0, \
+\
+    0, 0, 0, 0, 0, 0, 0 \
 }
 
 /* clang-format on */
@@ -91,6 +93,14 @@ struct options {
     char* group;
 
     size_t pcap_buffer_size;
+
+    int    use_layers;
+    int    defrag_ipv4;
+    size_t max_ipv4_fragments;
+    size_t max_ipv4_fragments_per_packet;
+    int    defrag_ipv6;
+    size_t max_ipv6_fragments;
+    size_t max_ipv6_fragments_per_packet;
 };
 
 int option_parse(options_t* options, const char* option);
